@@ -520,7 +520,7 @@ class ResponseDataInterview(NamedTuple):
     Represents the data payload for responding to an interview request.
     """
 
-    resp_cmd: str
+    resp_cmd: CommandType
     """Response command for the interview (e.g., accept, reject)."""
 
     ses_id: str
@@ -538,14 +538,13 @@ class ResponseDataInterview(NamedTuple):
     @classmethod
     def make(
         cls,
-        resp_cmd: str,
         ses_id: str,
         payload_id: str,
         ref_payload_id: str,
         text: Optional[str] = None
     ) -> 'ResponseDataInterview':
         """Factory method to create a `ResponseDataInterview` object."""
-        return cls(resp_cmd, ses_id, payload_id, ref_payload_id, text)
+        return cls(CommandType.INTERVIEW, ses_id, payload_id, ref_payload_id, text)
 
 
 class RequestDataHeartbeat(NamedTuple):
@@ -839,6 +838,7 @@ class RequestDataSms(NamedTuple):
     text: str
     """The text content of the SMS."""
 
+
 class RequestDataRest(NamedTuple):
     """
     Represents the data payload for an REST channel message.
@@ -899,9 +899,9 @@ class ResponseDataSlack(NamedTuple):
     def make(
         cls,
         channel: str,
-        text: Optional[str],
-        thread_ts: Optional[str],
-        files: Optional[list[File]]
+        text: Optional[str] = None,
+        thread_ts: Optional[str] = None,
+        files: Optional[list[File]] = None
     ) -> 'ResponseDataSlack':
         """Factory method to create a `ResponseDataSlack` object."""
         if not text and not files:
@@ -984,6 +984,7 @@ class ResponseDataSms(NamedTuple):
         """Factory method to create a `ResponseDataSms` object."""
         return cls(sender, receiver, text)
 
+
 class ResponseDataRest(NamedTuple):
     """
     Represents the data payload for the response to a REST channel request.
